@@ -27,9 +27,13 @@
  * @property string $user_registered
  * @property string $user_activation_key
  * @property string $user_status
+ * @property int    $user_level
  * @property string $display_name
  * @property string $spam
  * @property string $deleted
+ * @property string $locale
+ * @property string $rich_editing
+ * @property string $syntax_highlighting
  */
 class WP_User {
 	/**
@@ -44,7 +48,6 @@ class WP_User {
 	 * The user's ID.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 * @var int
 	 */
 	public $ID = 0;
@@ -53,7 +56,6 @@ class WP_User {
 	 * The individual capabilities the user has been given.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var array
 	 */
 	public $caps = array();
@@ -62,7 +64,6 @@ class WP_User {
 	 * User metadata option name.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var string
 	 */
 	public $cap_key;
@@ -71,7 +72,6 @@ class WP_User {
 	 * The roles the user is part of.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 * @var array
 	 */
 	public $roles = array();
@@ -80,8 +80,8 @@ class WP_User {
 	 * All capabilities the user has, including individual and role based.
 	 *
 	 * @since 2.0.0
-	 * @access public
-	 * @var array
+	 * @var bool[] Array of key/value pairs where keys represent a capability name and boolean values
+	 *             represent whether the user has that capability.
 	 */
 	public $allcaps = array();
 
@@ -89,14 +89,20 @@ class WP_User {
 	 * The filter context applied to user data fields.
 	 *
 	 * @since 2.9.0
-	 * @access private
 	 * @var string
 	 */
-	var $filter = null;
+	public $filter = null;
 
 	/**
-	 * @static
-	 * @access private
+	 * The site ID the capabilities of this user are initialized for.
+	 *
+	 * @since 4.9.0
+	 * @var int
+	 */
+	private $site_id = 0;
+
+	/**
+	 * @since 3.3.0
 	 * @var array
 	 */
 	private static $back_compat_keys;
@@ -107,38 +113,35 @@ class WP_User {
 	 * Retrieves the userdata and passes it to WP_User::init().
 	 *
 	 * @since 2.0.0
-	 * @access public
-	 *
-	 * @global wpdb $wpdb WordPress database abstraction object.
 	 *
 	 * @param int|string|stdClass|WP_User $id User's ID, a WP_User object, or a user object from the DB.
 	 * @param string $name Optional. User's username
-	 * @param int $blog_id Optional Site ID, defaults to current site.
+	 * @param int $site_id Optional Site ID, defaults to current site.
 	 */
-	public function __construct( $id = 0, $name = '', $blog_id = '' ) {
+	public function __construct( $id = 0, $name = '', $site_id = '' ) {
 		if ( ! isset( self::$back_compat_keys ) ) {
-			$prefix = $GLOBALS['wpdb']->prefix;
+			$prefix                 = $GLOBALS['wpdb']->prefix;
 			self::$back_compat_keys = array(
-				'user_firstname' => 'first_name',
-				'user_lastname' => 'last_name',
-				'user_description' => 'description',
-				'user_level' => $prefix . 'user_level',
-				$prefix . 'usersettings' => $prefix . 'user-settings',
+				'user_firstname'             => 'first_name',
+				'user_lastname'              => 'last_name',
+				'user_description'           => 'description',
+				'user_level'                 => $prefix . 'user_level',
+				$prefix . 'usersettings'     => $prefix . 'user-settings',
 				$prefix . 'usersettingstime' => $prefix . 'user-settings-time',
 			);
 		}
 
 		if ( $id instanceof WP_User ) {
-			$this->init( $id->data, $blog_id );
+			$this->init( $id->data, $site_id );
 			return;
 		} elseif ( is_object( $id ) ) {
-			$this->init( $id, $blog_id );
+			$this->init( $id, $site_id );
 			return;
 		}
 
 		if ( ! empty( $id ) && ! is_numeric( $id ) ) {
 			$name = $id;
-			$id = 0;
+			$id   = 0;
 		}
 
 		if ( $id ) {
@@ -148,7 +151,7 @@ class WP_User {
 		}
 
 		if ( $data ) {
-			$this->init( $data, $blog_id );
+			$this->init( $data, $site_id );
 		} else {
 			$this->data = new stdClass;
 		}
@@ -157,14 +160,16 @@ class WP_User {
 	/**
 	 * Sets up object properties, including capabilities.
 	 *
+	 * @since  3.3.0
+	 *
 	 * @param object $data    User DB row object.
-	 * @param int    $blog_id Optional. The site ID to initialize for.
+	 * @param int    $site_id Optional. The site ID to initialize for.
 	 */
-	public function init( $data, $blog_id = '' ) {
+	public function init( $data, $site_id = '' ) {
 		$this->data = $data;
-		$this->ID = (int) $data->ID;
+		$this->ID   = (int) $data->ID;
 
-		$this->for_blog( $blog_id );
+		$this->for_site( $site_id );
 	}
 
 	/**
@@ -173,8 +178,6 @@ class WP_User {
 	 * @since 3.3.0
 	 * @since 4.4.0 Added 'ID' as an alias of 'id' for the `$field` parameter.
 	 *
-	 * @static
-	 *
 	 * @global wpdb $wpdb WordPress database abstraction object.
 	 *
 	 * @param string $field The field to query against: 'id', 'ID', 'slug', 'email' or 'login'.
@@ -192,34 +195,37 @@ class WP_User {
 		if ( 'id' == $field ) {
 			// Make sure the value is numeric to avoid casting objects, for example,
 			// to int 1.
-			if ( ! is_numeric( $value ) )
+			if ( ! is_numeric( $value ) ) {
 				return false;
+			}
 			$value = intval( $value );
-			if ( $value < 1 )
+			if ( $value < 1 ) {
 				return false;
+			}
 		} else {
 			$value = trim( $value );
 		}
 
-		if ( !$value )
+		if ( ! $value ) {
 			return false;
+		}
 
 		switch ( $field ) {
 			case 'id':
-				$user_id = $value;
+				$user_id  = $value;
 				$db_field = 'ID';
 				break;
 			case 'slug':
-				$user_id = wp_cache_get($value, 'userslugs');
+				$user_id  = wp_cache_get( $value, 'userslugs' );
 				$db_field = 'user_nicename';
 				break;
 			case 'email':
-				$user_id = wp_cache_get($value, 'useremail');
+				$user_id  = wp_cache_get( $value, 'useremail' );
 				$db_field = 'user_email';
 				break;
 			case 'login':
-				$value = sanitize_user( $value );
-				$user_id = wp_cache_get($value, 'userlogins');
+				$value    = sanitize_user( $value );
+				$user_id  = wp_cache_get( $value, 'userlogins' );
 				$db_field = 'user_login';
 				break;
 			default:
@@ -227,49 +233,38 @@ class WP_User {
 		}
 
 		if ( false !== $user_id ) {
-			if ( $user = wp_cache_get( $user_id, 'users' ) )
+			if ( $user = wp_cache_get( $user_id, 'users' ) ) {
 				return $user;
+			}
 		}
 
-		if ( !$user = $wpdb->get_row( $wpdb->prepare(
-			"SELECT * FROM $wpdb->users WHERE $db_field = %s", $value
-		) ) )
+		if ( ! $user = $wpdb->get_row(
+			$wpdb->prepare(
+				"SELECT * FROM $wpdb->users WHERE $db_field = %s LIMIT 1",
+				$value
+			)
+		) ) {
 			return false;
+		}
 
 		update_user_caches( $user );
 
 		return $user;
 	}
 
-	/**
-	 * Makes private/protected methods readable for backward compatibility.
-	 *
-	 * @since 4.3.0
-	 * @access public
-	 *
-	 * @param callable $name      Method to call.
-	 * @param array    $arguments Arguments to pass when calling.
-	 * @return mixed|false Return value of the callback, false otherwise.
-	 */
-	public function __call( $name, $arguments ) {
-		if ( '_init_caps' === $name ) {
-			return call_user_func_array( array( $this, $name ), $arguments );
-		}
-		return false;
-	}
-
 	/**
 	 * Magic method for checking the existence of a certain custom field.
 	 *
 	 * @since 3.3.0
-	 * @access public
 	 *
 	 * @param string $key User meta key to check if set.
 	 * @return bool Whether the given user meta key is set.
 	 */
 	public function __isset( $key ) {
 		if ( 'id' == $key ) {
-			_deprecated_argument( 'WP_User->id', '2.1.0',
+			_deprecated_argument(
+				'WP_User->id',
+				'2.1.0',
 				sprintf(
 					/* translators: %s: WP_User->ID */
 					__( 'Use %s instead.' ),
@@ -279,11 +274,13 @@ class WP_User {
 			$key = 'ID';
 		}
 
-		if ( isset( $this->data->$key ) )
+		if ( isset( $this->data->$key ) ) {
 			return true;
+		}
 
-		if ( isset( self::$back_compat_keys[ $key ] ) )
+		if ( isset( self::$back_compat_keys[ $key ] ) ) {
 			$key = self::$back_compat_keys[ $key ];
+		}
 
 		return metadata_exists( 'user', $this->ID, $key );
 	}
@@ -292,14 +289,15 @@ class WP_User {
 	 * Magic method for accessing custom fields.
 	 *
 	 * @since 3.3.0
-	 * @access public
 	 *
 	 * @param string $key User meta key to retrieve.
 	 * @return mixed Value of the given user meta key (if set). If `$key` is 'id', the user ID.
 	 */
 	public function __get( $key ) {
 		if ( 'id' == $key ) {
-			_deprecated_argument( 'WP_User->id', '2.1.0',
+			_deprecated_argument(
+				'WP_User->id',
+				'2.1.0',
 				sprintf(
 					/* translators: %s: WP_User->ID */
 					__( 'Use %s instead.' ),
@@ -312,8 +310,9 @@ class WP_User {
 		if ( isset( $this->data->$key ) ) {
 			$value = $this->data->$key;
 		} else {
-			if ( isset( self::$back_compat_keys[ $key ] ) )
+			if ( isset( self::$back_compat_keys[ $key ] ) ) {
 				$key = self::$back_compat_keys[ $key ];
+			}
 			$value = get_user_meta( $this->ID, $key, true );
 		}
 
@@ -331,14 +330,15 @@ class WP_User {
 	 * the value on the WP_User instance.
 	 *
 	 * @since 3.3.0
-	 * @access public
 	 *
 	 * @param string $key   User meta key.
 	 * @param mixed  $value User meta value.
 	 */
 	public function __set( $key, $value ) {
 		if ( 'id' == $key ) {
-			_deprecated_argument( 'WP_User->id', '2.1.0',
+			_deprecated_argument(
+				'WP_User->id',
+				'2.1.0',
 				sprintf(
 					/* translators: %s: WP_User->ID */
 					__( 'Use %s instead.' ),
@@ -356,13 +356,14 @@ class WP_User {
 	 * Magic method for unsetting a certain custom field.
 	 *
 	 * @since 4.4.0
-	 * @access public
 	 *
 	 * @param string $key User meta key to unset.
 	 */
 	public function __unset( $key ) {
 		if ( 'id' == $key ) {
-			_deprecated_argument( 'WP_User->id', '2.1.0',
+			_deprecated_argument(
+				'WP_User->id',
+				'2.1.0',
 				sprintf(
 					/* translators: %s: WP_User->ID */
 					__( 'Use %s instead.' ),
@@ -384,7 +385,6 @@ class WP_User {
 	 * Determine whether the user exists in the database.
 	 *
 	 * @since 3.4.0
-	 * @access public
 	 *
 	 * @return bool True if user exists in the database, false if not.
 	 */
@@ -431,6 +431,22 @@ class WP_User {
 		return get_object_vars( $this->data );
 	}
 
+	/**
+	 * Makes private/protected methods readable for backward compatibility.
+	 *
+	 * @since 4.3.0
+	 *
+	 * @param string   $name      Method to call.
+	 * @param array    $arguments Arguments to pass when calling.
+	 * @return mixed|false Return value of the callback, false otherwise.
+	 */
+	public function __call( $name, $arguments ) {
+		if ( '_init_caps' === $name ) {
+			return call_user_func_array( array( $this, $name ), $arguments );
+		}
+		return false;
+	}
+
 	/**
 	 * Set up capability object properties.
 	 *
@@ -439,8 +455,8 @@ class WP_User {
 	 * property matching the 'cap_key' exists and is an array. If so, it will be
 	 * used.
 	 *
-	 * @access protected
 	 * @since 2.1.0
+	 * @deprecated 4.9.0 Use WP_User::for_site()
 	 *
 	 * @global wpdb $wpdb WordPress database abstraction object.
 	 *
@@ -449,47 +465,57 @@ class WP_User {
 	protected function _init_caps( $cap_key = '' ) {
 		global $wpdb;
 
-		if ( empty($cap_key) )
-			$this->cap_key = $wpdb->get_blog_prefix() . 'capabilities';
-		else
+		_deprecated_function( __METHOD__, '4.9.0', 'WP_User::for_site()' );
+
+		if ( empty( $cap_key ) ) {
+			$this->cap_key = $wpdb->get_blog_prefix( $this->site_id ) . 'capabilities';
+		} else {
 			$this->cap_key = $cap_key;
+		}
 
-		$this->caps = get_user_meta( $this->ID, $this->cap_key, true );
-
-		if ( ! is_array( $this->caps ) )
-			$this->caps = array();
+		$this->caps = $this->get_caps_data();
 
 		$this->get_role_caps();
 	}
 
 	/**
-	 * Retrieve all of the role capabilities and merge with individual capabilities.
+	 * Retrieves all of the capabilities of the roles of the user, and merges them with individual user capabilities.
 	 *
-	 * All of the capabilities of the roles the user belongs to are merged with
-	 * the users individual roles. This also means that the user can be denied
-	 * specific roles that their role might have, but the specific user isn't
-	 * granted permission to.
+	 * All of the capabilities of the roles of the user are merged with the user's individual capabilities. This means
+	 * that the user can be denied specific capabilities that their role might have, but the user is specifically denied.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
-	 * @return array List of all capabilities for the user.
+	 * @return bool[] Array of key/value pairs where keys represent a capability name and boolean values
+	 *                represent whether the user has that capability.
 	 */
 	public function get_role_caps() {
+		$switch_site = false;
+		if ( is_multisite() && $this->site_id != get_current_blog_id() ) {
+			$switch_site = true;
+
+			switch_to_blog( $this->site_id );
+		}
+
 		$wp_roles = wp_roles();
 
-		//Filter out caps that are not role names and assign to $this->roles
-		if ( is_array( $this->caps ) )
+		// Filter out caps that are not role names and assign to $this->roles.
+		if ( is_array( $this->caps ) ) {
 			$this->roles = array_filter( array_keys( $this->caps ), array( $wp_roles, 'is_role' ) );
+		}
 
-		//Build $allcaps from role caps, overlay user's $caps
+		// Build $allcaps from role caps, overlay user's $caps.
 		$this->allcaps = array();
 		foreach ( (array) $this->roles as $role ) {
-			$the_role = $wp_roles->get_role( $role );
+			$the_role      = $wp_roles->get_role( $role );
 			$this->allcaps = array_merge( (array) $this->allcaps, (array) $the_role->capabilities );
 		}
 		$this->allcaps = array_merge( (array) $this->allcaps, (array) $this->caps );
 
+		if ( $switch_site ) {
+			restore_current_blog();
+		}
+
 		return $this->allcaps;
 	}
 
@@ -499,7 +525,6 @@ class WP_User {
 	 * Updates the user's meta data option with capabilities and roles.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string $role Role name.
 	 */
@@ -508,7 +533,7 @@ class WP_User {
 			return;
 		}
 
-		$this->caps[$role] = true;
+		$this->caps[ $role ] = true;
 		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 		$this->update_user_level_from_caps();
@@ -528,14 +553,14 @@ class WP_User {
 	 * Remove role from user.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string $role Role name.
 	 */
 	public function remove_role( $role ) {
-		if ( !in_array($role, $this->roles) )
+		if ( ! in_array( $role, $this->roles ) ) {
 			return;
-		unset( $this->caps[$role] );
+		}
+		unset( $this->caps[ $role ] );
 		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 		$this->update_user_level_from_caps();
@@ -559,21 +584,22 @@ class WP_User {
 	 * of the roles from the user.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string $role Role name.
 	 */
 	public function set_role( $role ) {
-		if ( 1 == count( $this->roles ) && $role == current( $this->roles ) )
+		if ( 1 == count( $this->roles ) && $role == current( $this->roles ) ) {
 			return;
+		}
 
-		foreach ( (array) $this->roles as $oldrole )
-			unset( $this->caps[$oldrole] );
+		foreach ( (array) $this->roles as $oldrole ) {
+			unset( $this->caps[ $oldrole ] );
+		}
 
 		$old_roles = $this->roles;
-		if ( !empty( $role ) ) {
-			$this->caps[$role] = true;
-			$this->roles = array( $role => true );
+		if ( ! empty( $role ) ) {
+			$this->caps[ $role ] = true;
+			$this->roles         = array( $role => true );
 		} else {
 			$this->roles = false;
 		}
@@ -587,9 +613,9 @@ class WP_User {
 		 * @since 2.9.0
 		 * @since 3.6.0 Added $old_roles to include an array of the user's previous roles.
 		 *
-		 * @param int    $user_id   The user ID.
-		 * @param string $role      The new role.
-		 * @param array  $old_roles An array of the user's previous roles.
+		 * @param int      $user_id   The user ID.
+		 * @param string   $role      The new role.
+		 * @param string[] $old_roles An array of the user's previous roles.
 		 */
 		do_action( 'set_user_role', $this->ID, $role, $old_roles );
 	}
@@ -607,7 +633,6 @@ class WP_User {
 	 * value.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param int $max Max level of user.
 	 * @param string $item Level capability name.
@@ -630,7 +655,6 @@ class WP_User {
 	 * the all of the capabilities that the user has.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @global wpdb $wpdb WordPress database abstraction object.
 	 */
@@ -644,13 +668,12 @@ class WP_User {
 	 * Add capability and grant or deny access to capability.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string $cap Capability name.
 	 * @param bool $grant Whether to grant capability to user.
 	 */
 	public function add_cap( $cap, $grant = true ) {
-		$this->caps[$cap] = $grant;
+		$this->caps[ $cap ] = $grant;
 		update_user_meta( $this->ID, $this->cap_key, $this->caps );
 		$this->get_role_caps();
 		$this->update_user_level_from_caps();
@@ -660,7 +683,6 @@ class WP_User {
 	 * Remove capability from user.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param string $cap Capability name.
 	 */
@@ -678,7 +700,6 @@ class WP_User {
 	 * Remove all of the capabilities of the user.
 	 *
 	 * @since 2.1.0
-	 * @access public
 	 *
 	 * @global wpdb $wpdb WordPress database abstraction object.
 	 */
@@ -691,28 +712,26 @@ class WP_User {
 	}
 
 	/**
-	 * Whether user has capability or role name.
+	 * Whether the user has a specific capability.
 	 *
-	 * While checking against particular roles in place of a capability is supported
-	 * in part, this practice is discouraged as it may produce unreliable results.
+	 * While checking against a role in place of a capability is supported in part, this practice is discouraged as it
+	 * may produce unreliable results.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @see map_meta_cap()
 	 *
 	 * @param string $cap           Capability name.
-	 * @param int    $object_id,... Optional. ID of the specific object to check against if `$cap` is a "meta" cap.
-	 *                              "Meta" capabilities, e.g. 'edit_post', 'edit_user', etc., are capabilities used
-	 *                              by map_meta_cap() to map to other "primitive" capabilities, e.g. 'edit_posts',
-	 *                              'edit_others_posts', etc. The parameter is accessed via func_get_args() and passed
-	 *                              to map_meta_cap().
-	 * @return bool Whether the current user has the given capability. If `$cap` is a meta cap and `$object_id` is
-	 *              passed, whether the current user has the given meta capability for the given object.
+	 * @param int    $object_id,... Optional. ID of a specific object to check against if `$cap` is a "meta" capability.
+	 *                              Meta capabilities such as `edit_post` and `edit_user` are capabilities used by
+	 *                              by the `map_meta_cap()` function to map to primitive capabilities that a user or
+	 *                              role has, such as `edit_posts` and `edit_others_posts`.
+	 * @return bool Whether the user has the given capability, or, if `$object_id` is passed, whether the user has
+	 *              the given capability for that object.
 	 */
 	public function has_cap( $cap ) {
 		if ( is_numeric( $cap ) ) {
-			_deprecated_argument( __FUNCTION__, '2.0.0', __('Usage of user levels by plugins and themes is deprecated. Use roles and capabilities instead.') );
+			_deprecated_argument( __FUNCTION__, '2.0.0', __( 'Usage of user levels is deprecated. Use capabilities instead.' ) );
 			$cap = $this->translate_level_to_cap( $cap );
 		}
 
@@ -722,8 +741,9 @@ class WP_User {
 
 		// Multisite super admin has all caps by definition, Unless specifically denied.
 		if ( is_multisite() && is_super_admin( $this->ID ) ) {
-			if ( in_array('do_not_allow', $caps) )
+			if ( in_array( 'do_not_allow', $caps ) ) {
 				return false;
+			}
 			return true;
 		}
 
@@ -731,22 +751,33 @@ class WP_User {
 		 * Dynamically filter a user's capabilities.
 		 *
 		 * @since 2.0.0
-		 * @since 3.7.0 Added the user object.
+		 * @since 3.7.0 Added the `$user` parameter.
 		 *
-		 * @param array   $allcaps An array of all the user's capabilities.
-		 * @param array   $caps    Actual capabilities for meta capability.
-		 * @param array   $args    Optional parameters passed to has_cap(), typically object ID.
-		 * @param WP_User $user    The user object.
+		 * @param bool[]   $allcaps Array of key/value pairs where keys represent a capability name and boolean values
+		 *                          represent whether the user has that capability.
+		 * @param string[] $caps    Required primitive capabilities for the requested capability.
+		 * @param array    $args {
+		 *     Arguments that accompany the requested capability check.
+		 *
+		 *     @type string    $0 Requested capability.
+		 *     @type int       $1 Concerned user ID.
+		 *     @type mixed  ...$2 Optional second and further parameters, typically object ID.
+		 * }
+		 * @param WP_User  $user    The user object.
 		 */
 		$capabilities = apply_filters( 'user_has_cap', $this->allcaps, $caps, $args, $this );
 
 		// Everyone is allowed to exist.
 		$capabilities['exist'] = true;
 
+		// Nobody is allowed to do things they are not allowed to do.
+		unset( $capabilities['do_not_allow'] );
+
 		// Must have ALL requested caps.
 		foreach ( (array) $caps as $cap ) {
-			if ( empty( $capabilities[ $cap ] ) )
+			if ( empty( $capabilities[ $cap ] ) ) {
 				return false;
+			}
 		}
 
 		return true;
@@ -758,7 +789,6 @@ class WP_User {
 	 * Prepends 'level_' to level number.
 	 *
 	 * @since 2.0.0
-	 * @access public
 	 *
 	 * @param int $level Level number, 1 to 10.
 	 * @return string
@@ -771,17 +801,66 @@ class WP_User {
 	 * Set the site to operate on. Defaults to the current site.
 	 *
 	 * @since 3.0.0
-	 *
-	 * @global wpdb $wpdb WordPress database abstraction object.
+	 * @deprecated 4.9.0 Use WP_User::for_site()
 	 *
 	 * @param int $blog_id Optional. Site ID, defaults to current site.
 	 */
 	public function for_blog( $blog_id = '' ) {
+		_deprecated_function( __METHOD__, '4.9.0', 'WP_User::for_site()' );
+
+		$this->for_site( $blog_id );
+	}
+
+	/**
+	 * Sets the site to operate on. Defaults to the current site.
+	 *
+	 * @since 4.9.0
+	 *
+	 * @global wpdb $wpdb WordPress database abstraction object.
+	 *
+	 * @param int $site_id Site ID to initialize user capabilities for. Default is the current site.
+	 */
+	public function for_site( $site_id = '' ) {
 		global $wpdb;
-		if ( ! empty( $blog_id ) )
-			$cap_key = $wpdb->get_blog_prefix( $blog_id ) . 'capabilities';
-		else
-			$cap_key = '';
-		$this->_init_caps( $cap_key );
+
+		if ( ! empty( $site_id ) ) {
+			$this->site_id = absint( $site_id );
+		} else {
+			$this->site_id = get_current_blog_id();
+		}
+
+		$this->cap_key = $wpdb->get_blog_prefix( $this->site_id ) . 'capabilities';
+
+		$this->caps = $this->get_caps_data();
+
+		$this->get_role_caps();
+	}
+
+	/**
+	 * Gets the ID of the site for which the user's capabilities are currently initialized.
+	 *
+	 * @since 4.9.0
+	 *
+	 * @return int Site ID.
+	 */
+	public function get_site_id() {
+		return $this->site_id;
+	}
+
+	/**
+	 * Gets the available user capabilities data.
+	 *
+	 * @since 4.9.0
+	 *
+	 * @return array User capabilities array.
+	 */
+	private function get_caps_data() {
+		$caps = get_user_meta( $this->ID, $this->cap_key, true );
+
+		if ( ! is_array( $caps ) ) {
+			return array();
+		}
+
+		return $caps;
 	}
 }
