@@ -31,6 +31,6 @@
 	?>
 
 	<div class="wp-embed-footer">
-		<?php the_embed_site_title() ?>
+		<?php the_embed_site_title(); ?>
 	</div>
 </div>
